Imports Microsoft.VisualBasic
Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports System.Data
Imports Syncfusion.Windows.Forms.Grid

Namespace Forum
	Public Class FrozenRow
		Public Sub New()
		End Sub

		'the FrozenRow grid
		Private FrozenRowGrid As GridControl = Nothing

		'the main grid
		Private grid As GridControlBase

		#Region "wiring the main grid"

		Private defaultHeight As Integer
		Public Sub WireFrozenRow(ByVal grid As GridControlBase)
			If Not FrozenRowGrid Is Nothing Then
				Throw New ArgumentException("grid already wired")
			End If

			Me.grid = grid

			Me.FrozenRowGrid = New GridControl()
			Me.FrozenRowGrid.ColCount = grid.Model.ColCount
			Me.FrozenRowGrid.RowCount = 1
			Me.FrozenRowGrid.Rows.Hidden(0) = True
			Me.FrozenRowGrid.VScrollBehavior = GridScrollbarMode.Disabled
			Me.FrozenRowGrid.HScrollBehavior = GridScrollbarMode.Disabled
			Me.FrozenRowGrid.TabStop = False
			Me.grid.Anchor = (CType((AnchorStyles.Top Or AnchorStyles.Left), AnchorStyles))

			Me.FrozenRowGrid.DefaultRowHeight = Me.grid.DefaultRowHeight
			Me.FrozenRowGrid.TableStyle = Me.grid.Model.TableStyle

			AddHandler FrozenRowGrid.Click, AddressOf FrozenRowGrid_Click
			AddHandler FrozenRowGrid.Model.QueryColWidth, AddressOf FrozenGrid_QueryColWidth
			AddHandler FrozenRowGrid.PrepareViewStyleInfo, AddressOf FrozenGrid_PrepareViewStyleInfo

			AddHandler grid.Model.ColWidthsChanged, AddressOf grid_ColWidthsChanged
			AddHandler grid.Layout, AddressOf grid_Layout
			AddHandler grid.LeftColChanged, AddressOf grid_LeftColChanged
			AddHandler grid.Model.ColsMoved, AddressOf grid_ColsMoved

			Me.grid.Controls.Add(Me.FrozenRowGrid)

			defaultHeight = Me.grid.ClientSize.Height

			SiteFrozenRow()
			PropertyChanges()
			Me.grid.Refresh()

		End Sub
		#End Region

		Public Sub SiteFrozenRow()
			Me.grid.ResetGridBounds()

			Me.grid.GridBounds = New Rectangle(Me.grid.GridBounds.X, Me.grid.GridBounds.Y, Me.grid.GridBounds.Width, Me.grid.GridBounds.Height - Me.grid.DefaultRowHeight)
			Dim height As Integer = Me.grid.GridBounds.Height + Me.grid.DefaultRowHeight

			Me.FrozenRowGrid.Location = New Point(0, height - Me.grid.DefaultRowHeight)

			Me.FrozenRowGrid.Size = New Size(Me.grid.ClientSize.Width, Me.grid.DefaultRowHeight)
			Me.FrozenRowGrid.Refresh()
			Me.grid.Refresh()
		End Sub

		Public Sub PropertyChanges()
			Me.FrozenRowGrid.ThemesEnabled = Me.grid.ThemesEnabled
'			if(grid.Model.RowCount < 15)
'				this.grid.Model.RowCount = 15;
			Dim bottomGridHeight As Integer = grid.DefaultRowHeight
			Dim temp As Integer = grid.Model.RowHeights.GetTotal(0, grid.Model.RowCount) + bottomGridHeight
			If (grid.Model.RowHeights.GetTotal(0, grid.Model.RowCount) + bottomGridHeight) < defaultHeight Then
				grid.ClientSize = New Size(grid.ClientSize.Width, (grid.Model.RowHeights.GetTotal(0, grid.Model.RowCount) + bottomGridHeight))
			Else
				grid.ClientSize = New Size(grid.ClientSize.Width, defaultHeight)
			End If

			Me.FrozenRowGrid.Refresh()
		End Sub

		#Region " Event Handlers on the main grid"

		Private Sub grid_ColsMoved(ByVal sender As Object, ByVal e As GridRangeMovedEventArgs)
			Me.FrozenRowGrid.Cols.MoveRange(e.From, e.Count, e.Target)
		End Sub

		Private Sub grid_ColWidthsChanged(ByVal sender As Object, ByVal e As GridRowColSizeChangedEventArgs)
			Me.FrozenRowGrid.Refresh()
		End Sub

		Private Sub grid_Layout(ByVal sender As Object, ByVal e As LayoutEventArgs)
			SiteFrozenRow()
		End Sub

		Private Sub grid_LeftColChanged(ByVal sender As Object, ByVal e As GridRowColIndexChangedEventArgs)
			Me.FrozenRowGrid.LeftColIndex = Me.grid.LeftColIndex
		End Sub
		#End Region

		#Region "Event handlers on the FrozenRow Grid"

		Private Sub FrozenGrid_PrepareViewStyleInfo(ByVal sender As Object, ByVal e As GridPrepareViewStyleInfoEventArgs)

			If e.ColIndex > 0 AndAlso e.RowIndex > 0 Then
				e.Style.Borders.Top = New GridBorder(GridBorderStyle.Dotted,Color.Black,GridBorderWeight.Thick)
			End If
			If e.ColIndex = 0 AndAlso e.RowIndex > 0 Then
				e.Style.CellValue = Me.grid.Model.RowCount+1
				e.Style.Interior = Me.grid.Model(1, 0).Interior
			End If
		End Sub

		Private Sub FrozenGrid_QueryColWidth(ByVal sender As Object, ByVal e As GridRowColSizeEventArgs)
			e.Size = Me.grid.Model.ColWidths(e.Index)
			e.Handled = True
		End Sub

		Private Sub FrozenRowGrid_Click(ByVal sender As Object, ByVal e As EventArgs)

		End Sub
		#End Region
	End Class
End Namespace